@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -74,7 +74,7 @@ class TaskHelper:
                                uri,
                                *args)
         except Exception as e:
-            Logger.error("HelperTask::load_uri_content(): %s, %s:",  e, uri)
+            Logger.error("HelperTask::load_uri_content(): %s, %s:", e, uri)
             callback(None, False, b"", *args)
 
 #######################
@@ -141,5 +141,5 @@ class TaskHelper:
                                     bytearray(0), cancellable, callback, uri,
                                     *args)
         except Exception as e:
-            Logger.error("TaskHelper::__on_soup_msg_finished(): %s",  e)
+            Logger.warning("TaskHelper::__on_request_send_async(): %s", e)
             callback(uri, False, b"", *args)
